@@ -1,7 +1,7 @@
 from twitchAPI.twitch import Twitch
 from twitchAPI.webhook import TwitchWebHook
 from twitchAPI.oauth import UserAuthenticator, refresh_access_token
-import twitchAPI.types
+from twitchAPI.types import *
 from twitchAPI.pubsub import PubSub
 
-VERSION = (2, 2, 3)
+VERSION = (2, 2, 4)
