@@ -151,7 +151,7 @@ class UserAuthenticator:
                 await asyncio.sleep(1)
             except (CancelledError, asyncio.CancelledError):
                 pass
-        for task in asyncio.Task.all_tasks(self.__loop):
+        for task in asyncio.all_tasks(self.__loop):
             task.cancel()
 
     def __run(self, runner: 'web.AppRunner'):
